jsToolBar.strings = {};
jsToolBar.strings['Strong'] = 'Negrita';
jsToolBar.strings['Italic'] = 'Itálica';
jsToolBar.strings['Underline'] = 'Subrayado';
jsToolBar.strings['Deleted'] = 'Tachado';
jsToolBar.strings['Code'] = 'Código fuente';
jsToolBar.strings['Heading 1'] = 'Encabezado 1';
jsToolBar.strings['Heading 2'] = 'Encabezado 2';
jsToolBar.strings['Heading 3'] = 'Encabezado 3';
jsToolBar.strings['Highlighted code'] = 'Código resaltado';
jsToolBar.strings['Unordered list'] = 'Lista sin ordenar';
jsToolBar.strings['Ordered list'] = 'Lista ordenada';
jsToolBar.strings['Quote'] = 'Citar';
jsToolBar.strings['Unquote'] = 'Quitar cita';
jsToolBar.strings['Preformatted text'] = 'Texto con formato';
jsToolBar.strings['Wiki link'] = 'Enlace a página Wiki';
jsToolBar.strings['Image'] = 'Imagen';
